# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_apl'},
  'syms': {'primitive_functions': {'+': 'https://help.dyalog.com/18.2/#Language/Symbols/Plus Sign.htm',
  '-': 'https://help.dyalog.com/18.2/#Language/Symbols/Minus Sign.htm',
  '×': 'https://help.dyalog.com/18.2/#Language/Symbols/Times Sign.htm',
  '÷': 'https://help.dyalog.com/18.2/#Language/Symbols/Divide Sign.htm',
  '|': 'https://help.dyalog.com/18.2/#Language/Symbols/Stile.htm',
  '⌈': 'https://help.dyalog.com/18.2/#Language/Symbols/Upstile.htm',
  '⌊': 'https://help.dyalog.com/18.2/#Language/Symbols/Downstile.htm',
  '*': 'https://help.dyalog.com/18.2/#Language/Symbols/Star.htm',
  '⍟': 'https://help.dyalog.com/18.2/#Language/Symbols/Log.htm',
  '○': 'https://help.dyalog.com/18.2/#Language/Symbols/Circle.htm',
  '!': 'https://help.dyalog.com/18.2/#Language/Symbols/Exclamation Mark.htm',
  '?': 'https://help.dyalog.com/18.2/#Language/Symbols/Question Mark.htm',
  '~': 'https://help.dyalog.com/18.2/#Language/Symbols/Tilde.htm',
  '∧': 'https://help.dyalog.com/18.2/#Language/Symbols/Logical And.htm',
  '∨': 'https://help.dyalog.com/18.2/#Language/Symbols/Logical Or.htm',
  '⍲': 'https://help.dyalog.com/18.2/#Language/Symbols/Nand Symbol.htm',
  '⍱': 'https://help.dyalog.com/18.2/#Language/Symbols/Nor Symbol.htm',
  '<': 'https://help.dyalog.com/18.2/#Language/Symbols/Less Than Sign.htm',
  '≤': 'https://help.dyalog.com/18.2/#Language/Symbols/Less Than Or Equal To Sign.htm',
  '=': 'https://help.dyalog.com/18.2/#Language/Symbols/Equal Sign.htm',
  '>': 'https://help.dyalog.com/18.2/#Language/Symbols/Greater Than Sign.htm',
  '≥': 'https://help.dyalog.com/18.2/#Language/Symbols/Greater Than Or Equal To Sign.htm',
  '≠': 'https://help.dyalog.com/18.2/#Language/Symbols/Not Equal To.htm',
  '≡': 'https://help.dyalog.com/18.2/#Language/Symbols/Equal Underbar.htm',
  '≢': 'https://help.dyalog.com/18.2/#Language/Symbols/Equal Underbar Slash.htm',
  '⍴': 'https://help.dyalog.com/18.2/#Language/Symbols/Rho.htm',
  ',': 'https://help.dyalog.com/18.2/#Language/Symbols/Comma.htm',
  '⍪': 'https://help.dyalog.com/18.2/#Language/Symbols/Comma Bar.htm',
  '⌽': 'https://help.dyalog.com/18.2/#Language/Symbols/Circle Stile.htm',
  '⊖': 'https://help.dyalog.com/18.2/#Language/Symbols/Circle Bar.htm',
  '⍉': 'https://help.dyalog.com/18.2/#Language/Symbols/Transpose.htm',
  '↑': 'https://help.dyalog.com/18.2/#Language/Symbols/Up Arrow.htm',
  '↓': 'https://help.dyalog.com/18.2/#Language/Symbols/Down Arrow.htm',
  '⊂': 'https://help.dyalog.com/18.2/#Language/Symbols/Left Shoe.htm',
  '⊆': 'https://help.dyalog.com/18.2/#Language/Symbols/Left Shoe Underbar.htm',
  '⊃': 'https://help.dyalog.com/18.2/#Language/Symbols/Right Shoe.htm',
  '∊': 'https://help.dyalog.com/18.2/#Language/Symbols/Epsilon.htm',
  '⍷': 'https://help.dyalog.com/18.2/#Language/Symbols/Epsilon Underbar.htm',
  '/': 'https://help.dyalog.com/18.2/#Language/Symbols/Slash.htm',
  '⌿': 'https://help.dyalog.com/18.2/#Language/Symbols/Slash Bar.htm',
  '\\': 'https://help.dyalog.com/18.2/#Language/Symbols/Slope.htm',
  '⍀': 'https://help.dyalog.com/18.2/#Language/Symbols/Slope Bar.htm',
  '∩': 'https://help.dyalog.com/18.2/#Language/Symbols/Set Intersection.htm',
  '∪': 'https://help.dyalog.com/18.2/#Language/Symbols/Set Union.htm',
  '⍳': 'https://help.dyalog.com/18.2/#Language/Symbols/Iota.htm',
  '⍸': 'https://help.dyalog.com/18.2/#Language/Symbols/Iota Underbar.htm',
  '⌷': 'https://help.dyalog.com/18.2/#Language/Symbols/Index Symbol.htm',
  '⍋': 'https://help.dyalog.com/18.2/#Language/Symbols/Grade Up.htm',
  '⍒': 'https://help.dyalog.com/18.2/#Language/Symbols/Grade Down.htm',
  '⍎': 'https://help.dyalog.com/18.2/#Language/Symbols/Execute Symbol.htm',
  '⍕': 'https://help.dyalog.com/18.2/#Language/Symbols/Thorn Symbol.htm',
  '⊥': 'https://help.dyalog.com/18.2/#Language/Symbols/Decode Symbol.htm',
  '⊤': 'https://help.dyalog.com/18.2/#Language/Symbols/Encode Symbol.htm',
  '⊣': 'https://help.dyalog.com/18.2/#Language/Symbols/Left Tack.htm',
  '⊢': 'https://help.dyalog.com/18.2/#Language/Symbols/Right Tack.htm',
  '⌹': 'https://help.dyalog.com/18.2/#Language/Symbols/Domino.htm',
  '⍬': 'https://help.dyalog.com/18.2/#Language/Symbols/Zilde Symbol.htm',
  '→': 'https://help.dyalog.com/18.2/#Language/Symbols/Right Arrow.htm',
  '←': 'https://help.dyalog.com/18.2/#Language/Symbols/Left Arrow.htm'},
 'primitive_operators': {'¨': 'https://help.dyalog.com/18.2/#Language/Symbols/Dieresis.htm',
  '⍨': 'https://help.dyalog.com/18.2/#Language/Symbols/Dieresis Tilde.htm',
  '∘': 'https://help.dyalog.com/18.2/#Language/Symbols/Jot.htm',
  '.': 'https://help.dyalog.com/18.2/#Language/Symbols/Dot.htm',
  '∘.': 'https://help.dyalog.com/18.2/#Language/Symbols/Outer Product.htm',
  '/': 'https://help.dyalog.com/18.2/#Language/Symbols/Slash.htm',
  '⌿': 'https://help.dyalog.com/18.2/#Language/Symbols/Slash Bar.htm',
  '\\': 'https://help.dyalog.com/18.2/#Language/Symbols/Slope.htm',
  '⍀': 'https://help.dyalog.com/18.2/#Language/Symbols/Slope Bar.htm',
  '⍣': 'https://help.dyalog.com/18.2/#Language/Symbols/DieresisStar.htm',
  '&': 'https://help.dyalog.com/18.2/#Language/Symbols/Ampersand.htm',
  '⌶': 'https://help.dyalog.com/18.2/#Language/Symbols/IBeam.htm#IBeam',
  '⍠': 'https://help.dyalog.com/18.2/#Language/Symbols/Variant.htm#Variant',
  '⌸': 'https://help.dyalog.com/18.2/#Language/Symbols/Quad Equal.htm',
  '⌺': 'https://help.dyalog.com/18.2/#Language/Symbols/Quad Diamond.htm',
  '⍤': 'https://help.dyalog.com/18.2/#Language/Symbols/Jot Diaresis.htm',
  '⍥': 'https://help.dyalog.com/18.2/#Language/Symbols/Circle Dieresis.htm',
  '@': 'https://help.dyalog.com/18.2/#Language/Symbols/At.htm'}}}